Class: Google::Cloud::OrgPolicy::V2::Constraint::BooleanConstraint

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/orgpolicy/v2/constraint.rb

Overview

A constraint type is enforced or not enforced, which is configured in the PolicyRule.

If customConstraintDefinition is defined, this constraint is a managed constraint.

Instance Attribute Summary collapse

Instance Attribute Details

#custom_constraint_definition::Google::Cloud::OrgPolicy::V2::Constraint::CustomConstraintDefinition

Returns Custom constraint definition. Defines this as a managed constraint.

Returns:



247
248
249
250
# File 'proto_docs/google/cloud/orgpolicy/v2/constraint.rb', line 247

class BooleanConstraint
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end