Class: Google::Cloud::OrgPolicy::V2::Constraint::CustomConstraintDefinition::Parameter

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/orgpolicy/v2/constraint.rb

Overview

Defines a parameter structure.

Defined Under Namespace

Modules: Type Classes: Metadata

Instance Attribute Summary collapse

Instance Attribute Details

#default_value::Google::Protobuf::Value

Returns Sets the value of the parameter in an assignment if no value is given.

Returns:



156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
# File 'proto_docs/google/cloud/orgpolicy/v2/constraint.rb', line 156

class Parameter
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Defines Metadata structure.
  # @!attribute [rw] description
  #   @return [::String]
  #     Detailed description of what this `parameter` is and use of it.
  #     Mutable.
  class Metadata
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # All valid types of parameter.
  module Type
    # This is only used for distinguishing unset values and should never be
    # used. Results in an error.
    TYPE_UNSPECIFIED = 0

    # List parameter type.
    LIST = 1

    # String parameter type.
    STRING = 2

    # Boolean parameter type.
    BOOLEAN = 3
  end
end

#item::Google::Cloud::OrgPolicy::V2::Constraint::CustomConstraintDefinition::Parameter::Type

Returns Determines the parameter's value structure. For example, LIST<STRING> can be specified by defining type: LIST, and item: STRING.

Returns:



156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
# File 'proto_docs/google/cloud/orgpolicy/v2/constraint.rb', line 156

class Parameter
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Defines Metadata structure.
  # @!attribute [rw] description
  #   @return [::String]
  #     Detailed description of what this `parameter` is and use of it.
  #     Mutable.
  class Metadata
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # All valid types of parameter.
  module Type
    # This is only used for distinguishing unset values and should never be
    # used. Results in an error.
    TYPE_UNSPECIFIED = 0

    # List parameter type.
    LIST = 1

    # String parameter type.
    STRING = 2

    # Boolean parameter type.
    BOOLEAN = 3
  end
end

#metadata::Google::Cloud::OrgPolicy::V2::Constraint::CustomConstraintDefinition::Parameter::Metadata

Returns Defines subproperties primarily used by the UI to display user-friendly information.

Returns:



156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
# File 'proto_docs/google/cloud/orgpolicy/v2/constraint.rb', line 156

class Parameter
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Defines Metadata structure.
  # @!attribute [rw] description
  #   @return [::String]
  #     Detailed description of what this `parameter` is and use of it.
  #     Mutable.
  class Metadata
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # All valid types of parameter.
  module Type
    # This is only used for distinguishing unset values and should never be
    # used. Results in an error.
    TYPE_UNSPECIFIED = 0

    # List parameter type.
    LIST = 1

    # String parameter type.
    STRING = 2

    # Boolean parameter type.
    BOOLEAN = 3
  end
end

#type::Google::Cloud::OrgPolicy::V2::Constraint::CustomConstraintDefinition::Parameter::Type

Returns Type of the parameter.



156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
# File 'proto_docs/google/cloud/orgpolicy/v2/constraint.rb', line 156

class Parameter
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Defines Metadata structure.
  # @!attribute [rw] description
  #   @return [::String]
  #     Detailed description of what this `parameter` is and use of it.
  #     Mutable.
  class Metadata
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # All valid types of parameter.
  module Type
    # This is only used for distinguishing unset values and should never be
    # used. Results in an error.
    TYPE_UNSPECIFIED = 0

    # List parameter type.
    LIST = 1

    # String parameter type.
    STRING = 2

    # Boolean parameter type.
    BOOLEAN = 3
  end
end

#valid_values_expr::String

Returns Provides a CEL expression to specify the acceptable parameter values during assignment. For example, parameterName in ("parameterValue1", "parameterValue2").

Returns:

  • (::String)

    Provides a CEL expression to specify the acceptable parameter values during assignment. For example, parameterName in ("parameterValue1", "parameterValue2")



156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
# File 'proto_docs/google/cloud/orgpolicy/v2/constraint.rb', line 156

class Parameter
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Defines Metadata structure.
  # @!attribute [rw] description
  #   @return [::String]
  #     Detailed description of what this `parameter` is and use of it.
  #     Mutable.
  class Metadata
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # All valid types of parameter.
  module Type
    # This is only used for distinguishing unset values and should never be
    # used. Results in an error.
    TYPE_UNSPECIFIED = 0

    # List parameter type.
    LIST = 1

    # String parameter type.
    STRING = 2

    # Boolean parameter type.
    BOOLEAN = 3
  end
end