Class: Google::Cloud::OrgPolicy::V2::Constraint::CustomConstraintDefinition::Parameter::Metadata

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/orgpolicy/v2/constraint.rb

Overview

Defines Metadata structure.

Instance Attribute Summary collapse

Instance Attribute Details

#description::String

Returns Detailed description of what this parameter is and use of it. Mutable.

Returns:

  • (::String)

    Detailed description of what this parameter is and use of it. Mutable.



165
166
167
168
# File 'proto_docs/google/cloud/orgpolicy/v2/constraint.rb', line 165

class Metadata
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end