Class: Google::Cloud::OrgPolicy::V2::Constraint::ListConstraint
- Inherits:
-
Object
- Object
- Google::Cloud::OrgPolicy::V2::Constraint::ListConstraint
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/orgpolicy/v2/constraint.rb
Overview
A constraint type that allows or disallows a list of string values, which
are configured in the
PolicyRule.
Instance Attribute Summary collapse
-
#supports_in ⇒ ::Boolean
Indicates whether values grouped into categories can be used in
Policy.allowed_valuesandPolicy.denied_values. -
#supports_under ⇒ ::Boolean
Indicates whether subtrees of the Resource Manager resource hierarchy can be used in
Policy.allowed_valuesandPolicy.denied_values.
Instance Attribute Details
#supports_in ⇒ ::Boolean
Returns Indicates whether values grouped into categories can be used in
Policy.allowed_values and Policy.denied_values. For example,
"in:Python" would match any value in the 'Python' group.
100 101 102 103 |
# File 'proto_docs/google/cloud/orgpolicy/v2/constraint.rb', line 100 class ListConstraint include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#supports_under ⇒ ::Boolean
Returns Indicates whether subtrees of the Resource Manager resource hierarchy
can be used in Policy.allowed_values and Policy.denied_values. For
example, "under:folders/123" would match any resource under the
'folders/123' folder.
100 101 102 103 |
# File 'proto_docs/google/cloud/orgpolicy/v2/constraint.rb', line 100 class ListConstraint include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |