Class: Google::Cloud::OrgPolicy::V2::DeletePolicyRequest
- Inherits:
-
Object
- Object
- Google::Cloud::OrgPolicy::V2::DeletePolicyRequest
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/orgpolicy/v2/orgpolicy.rb
Overview
The request sent to the [DeletePolicy] [google.cloud.orgpolicy.v2.OrgPolicy.DeletePolicy] method.
Instance Attribute Summary collapse
-
#etag ⇒ ::String
Optional.
-
#name ⇒ ::String
Required.
Instance Attribute Details
#etag ⇒ ::String
Returns Optional. The current etag of policy. If an etag is provided and does not match the current etag of the policy, deletion will be blocked and an ABORTED error will be returned.
360 361 362 363 |
# File 'proto_docs/google/cloud/orgpolicy/v2/orgpolicy.rb', line 360 class DeletePolicyRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#name ⇒ ::String
Returns Required. Name of the policy to delete. See the policy entry for naming rules.
360 361 362 363 |
# File 'proto_docs/google/cloud/orgpolicy/v2/orgpolicy.rb', line 360 class DeletePolicyRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |