Class: Google::Cloud::OrgPolicy::V2::ListConstraintsRequest
- Inherits:
-
Object
- Object
- Google::Cloud::OrgPolicy::V2::ListConstraintsRequest
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/orgpolicy/v2/orgpolicy.rb
Overview
The request sent to the [ListConstraints] [google.cloud.orgpolicy.v2.OrgPolicy.ListConstraints] method.
Instance Attribute Summary collapse
-
#page_size ⇒ ::Integer
Size of the pages to be returned.
-
#page_token ⇒ ::String
Page token used to retrieve the next page.
-
#parent ⇒ ::String
Required.
Instance Attribute Details
#page_size ⇒ ::Integer
Returns Size of the pages to be returned. This is currently unsupported and will be ignored. The server may at any point start using this field to limit page size.
233 234 235 236 |
# File 'proto_docs/google/cloud/orgpolicy/v2/orgpolicy.rb', line 233 class ListConstraintsRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#page_token ⇒ ::String
Returns Page token used to retrieve the next page. This is currently unsupported and will be ignored. The server may at any point start using this field.
233 234 235 236 |
# File 'proto_docs/google/cloud/orgpolicy/v2/orgpolicy.rb', line 233 class ListConstraintsRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#parent ⇒ ::String
Returns Required. The Google Cloud resource that parents the constraint. Must be in one of the following forms:
projects/{project_number}projects/{project_id}folders/{folder_id}organizations/{organization_id}.
233 234 235 236 |
# File 'proto_docs/google/cloud/orgpolicy/v2/orgpolicy.rb', line 233 class ListConstraintsRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |