Class: Google::Cloud::OrgPolicy::V2::ListCustomConstraintsRequest
- Inherits:
-
Object
- Object
- Google::Cloud::OrgPolicy::V2::ListCustomConstraintsRequest
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/orgpolicy/v2/orgpolicy.rb
Overview
The request sent to the [ListCustomConstraints] [google.cloud.orgpolicy.v2.OrgPolicy.ListCustomConstraints] method.
Instance Attribute Summary collapse
-
#page_size ⇒ ::Integer
Size of the pages to be returned.
-
#page_token ⇒ ::String
Page token used to retrieve the next page.
-
#parent ⇒ ::String
Required.
Instance Attribute Details
#page_size ⇒ ::Integer
Returns Size of the pages to be returned. This is currently unsupported and will be ignored. The server may at any point start using this field to limit page size.
409 410 411 412 |
# File 'proto_docs/google/cloud/orgpolicy/v2/orgpolicy.rb', line 409 class ListCustomConstraintsRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#page_token ⇒ ::String
Returns Page token used to retrieve the next page. This is currently unsupported and will be ignored. The server may at any point start using this field.
409 410 411 412 |
# File 'proto_docs/google/cloud/orgpolicy/v2/orgpolicy.rb', line 409 class ListCustomConstraintsRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#parent ⇒ ::String
Returns Required. The target Google Cloud resource that parents the set of custom constraints that will be returned from this call. Must be in one of the following forms:
organizations/{organization_id}.
409 410 411 412 |
# File 'proto_docs/google/cloud/orgpolicy/v2/orgpolicy.rb', line 409 class ListCustomConstraintsRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |